Learn R Programming

ff (version 4.0.4)

maxffmode: Lossless vmode coercability

Description

maxffmode returns the lowest vmode that can absorb all input vmodes without data loss

Usage

maxffmode(...)

Arguments

…

one or more vectors of vmodes

Value

the smallest .ffmode which can absorb the input vmodes without data loss

See Also

.vcoerceable, .ffmode, ffconform

Examples

Run this code
# NOT RUN {
   maxffmode(c("quad","logical"), "ushort")
# }

Run the code above in your browser using DataLab